# GeoTex: Expose the UV unwrapping from Geogram for Python

Small wrapper to expose the UV unwrapping related functions from [Geogram](https://github.com/BrunoLevy/geogram).

## Installation

Either via [Pypi](https://pypi.org/project/geotex) or install via github `pip install git+https://github.com/vork/geotex.git`.

## Usage

Check the [unit tests](tests/test_geotex.py) for an example overview.

## License

The project is licensed under [BSD 3](LICENSE)

Geogram is also licensed under [BSD 3](https://github.com/BrunoLevy/geogram/blob/main/LICENSE).
